==> gst-plugins-good-0.10.1.tar.bz2: gst-plugins-good-0.10.1/gst/rtp/gstrtpmpapay.h <==
/* Gnome-Streamer
 * Copyright (C) <2005> Wim Taymans <wim@fluendo.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GST_RTP_MPA_PAY_H__
#define __GST_RTP_MPA_PAY_H__

#include <gst/gst.h>
#include <gst/rtp/gstbasertppayload.h>
#include <gst/base/gstadapter.h>

G_BEGIN_DECLS

#define GST_TYPE_RTP_MPA_PAY \
  (gst_rtp_mpa_pay_get_type())
#define GST_RTP_MPA_PAY(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST((obj),GST_TYPE_RTP_MPA_PAY,GstRtpMPAPay))
#define GST_RTP_MPA_PAY_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_RTP_MPA_PAY,GstRtpMPAPay))
#define GST_IS_RTP_MPA_PAY(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_RTP_MPA_PAY))
#define GST_IS_RTP_MPA_PAY_CLASS(obj) \
  (G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_RTP_MPA_PAY))

typedef struct _GstRtpMPAPay GstRtpMPAPay;
typedef struct _GstRtpMPAPayClass GstRtpMPAPayClass;

struct _GstRtpMPAPay
{
  GstBaseRTPPayload payload;

  GstAdapter *adapter;
  GstClockTime first_ts;
  GstClockTime duration;
};

struct _GstRtpMPAPayClass
{
  GstBaseRTPPayloadClass parent_class;
};

gboolean gst_rtp_mpa_pay_plugin_init (GstPlugin * plugin);

G_END_DECLS

#endif /* __GST_RTP_MPA_PAY_H__ */

==> gst-plugins-good-0.10.6.tar.bz2: gst-plugins-good-0.10.6/gst/rtp/gstrtpmpapay.h <==
/* GStreamer
 * Copyright (C) <2005> Wim Taymans <wim@fluendo.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GST_RTP_MPA_PAY_H__
#define __GST_RTP_MPA_PAY_H__

#include <gst/gst.h>
#include <gst/rtp/gstbasertppayload.h>
#include <gst/base/gstadapter.h>

G_BEGIN_DECLS

#define GST_TYPE_RTP_MPA_PAY \
  (gst_rtp_mpa_pay_get_type())
#define GST_RTP_MPA_PAY(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST((obj),GST_TYPE_RTP_MPA_PAY,GstRtpMPAPay))
#define GST_RTP_MPA_PAY_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_RTP_MPA_PAY,GstRtpMPAPayClass))
#define GST_IS_RTP_MPA_PAY(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_RTP_MPA_PAY))
#define GST_IS_RTP_MPA_PAY_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_RTP_MPA_PAY))

typedef struct _GstRtpMPAPay GstRtpMPAPay;
typedef struct _GstRtpMPAPayClass GstRtpMPAPayClass;

struct _GstRtpMPAPay
{
  GstBaseRTPPayload payload;

  GstAdapter *adapter;
  GstClockTime first_ts;
  GstClockTime duration;
};

struct _GstRtpMPAPayClass
{
  GstBaseRTPPayloadClass parent_class;
};

gboolean gst_rtp_mpa_pay_plugin_init (GstPlugin * plugin);

G_END_DECLS

#endif /* __GST_RTP_MPA_PAY_H__ */
